================
Nimbus-Inference
================

.. toctree::
   :maxdepth: 2
   :caption: The Basics

   tutorial/installation
   tutorial/getting_started

.. toctree::
   :maxdepth: 2
   :caption: Documentation
   
   docu/nimbus_inference
